@@ -1,4 +1,4 @@
-# Copyright 2016-2018 California Institute of Technology.
+# Copyright 2016-2019 California Institute of Technology.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,19 +18,20 @@ from future.moves.urllib.parse import urlparse
 import os
 
 SEARCH_URL = 'https://oceandata.sci.gsfc.nasa.gov/api/file_search?'
-#GET_URL = 'https://oceandata.sci.gsfc.nasa.gov/cgi/getfile/'
+# GET_URL = 'https://oceandata.sci.gsfc.nasa.gov/cgi/getfile/'
 HEADERS = {
     'User-Agent': 'Podaacpy Python Library'
 }
 
 class OceanColor:
 
+    
     def __init__(self):
         self.SEARCH_URL = 'https://oceandata.sci.gsfc.nasa.gov/api/file_search?'
-        #self.GET_URL = 'https://oceandata.sci.gsfc.nasa.gov/cgi/getfile/'
+        # self.GET_URL = 'https://oceandata.sci.gsfc.nasa.gov/cgi/getfile/'
 
     def file_search(self, sensor='', sdate='', edate='', dtype='', add_url='1', results_as_file='1',
-                       search='', sub_id='', std_only='1', cksum='', output_format='json'):
+                    search='', sub_id='', std_only='1', cksum='', output_format='json'):
         '''File search service retrieves publically available files within the \
                 NASA Ocean Data Processing System.
 
@@ -113,7 +114,7 @@ class OceanColor:
             print(error)
             raise
 
-        return response.text
+        return str(response.text)
 
     def get_file(self, url='', path=''):
         '''It is possible to mimic FTP bulk data downloads using the \
@@ -133,19 +134,20 @@ class OceanColor:
 
         '''
         try:
-            #url = GET_URL
+            # url = GET_URL
             if url:
                 url = url
             else:
                 raise Exception("'file' parameter is required!")
             file = os.path.basename(urlparse(url).path)
             if path == '':
-            	path = os.path.join(os.path.dirname(__file__), file)
+                path = os.path.join(os.path.dirname(__file__), file)
             else:
                 path = path + '/' + file
             urlretrieve(url, path)
             print("Downloaded '%s' to '%s'" % (file, path))
             return file
 
-        except Exception:
+        except Exception as e:
+            print(e)
             raise
