@@ -1,4 +1,4 @@
-# Copyright 2016-2018 California Institute of Technology.
+# Copyright 2016-2019 California Institute of Technology.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 
 from bs4 import BeautifulSoup
 import requests
-import xml.etree.ElementTree as ET
+import defusedxml.ElementTree as ET
 try:
     from . import podaac as p
 except:
@@ -22,6 +22,7 @@ except:
 
 class PodaacUtils:
 
+    
     def __init__(self):
         self.URL = 'https://podaac.jpl.nasa.gov/ws/'
 
@@ -219,8 +220,8 @@ class PodaacUtils:
         '''
         search_str = '<title>'
         granule_list = \
-            [ str(i) for i in granule_search_response.strip().split() 
-                if search_str in i and 'PO.DAAC' not in i ]
+            [str(i) for i in granule_search_response.strip().split() 
+                if search_str in i and 'PO.DAAC' not in i]
         strp_granule_list = \
-            [ i.replace('<title>','').replace('</title>','') for i in granule_list ]
+            [i.replace('<title>','').replace('</title>','') for i in granule_list]
         return strp_granule_list
