@@ -1,4 +1,4 @@
-# Copyright 2016-2018 California Institute of Technology.
+# Copyright 2016-2019 California Institute of Technology.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,18 +14,15 @@
 
 from ..oceancolor import OceanColor
 import os
-import requests
-import xml.etree.ElementTree as ET
 from nose.tools import assert_raises
 import unittest
-from future.moves.urllib.error import HTTPError
 
 
 class TestOceanColor(unittest.TestCase):
 
     @classmethod
-    def setUp(self):
-        self.oceancolor = OceanColor()
+    def setUp(cls):
+        cls.oceancolor = OceanColor()
 
     # test case for the function file_search()
     def test_file_search(self):
@@ -33,10 +30,13 @@ class TestOceanColor(unittest.TestCase):
                 dtype='L3b', add_url='1', results_as_file='1', search='*DAY_CHL*')
 
         assert data != None
-        print(data)
-        assert type(data) is type(u'')
+        assert isinstance(data, str)
         assert len(data) != 0
 
+        # must have a valid sensor AND either 'search' OR 'sub-id'
+        data2 = self.oceancolor.file_search(sensor='octs', sub_id='2218')
+        assert data2 != None
+
         assert_raises(Exception, self.oceancolor.file_search, sensor='random')
         assert_raises(Exception, self.oceancolor.file_search, sdate='1996-11-01', edate='1997-01-01',
                 dtype='L3b', add_url='1', results_as_file='1', search='*DAY_CHL*')
